cgexplore.terms.TargetBond
==========================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetBond
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetBond.human_readable
      ~TargetBond.vector
      ~TargetBond.vector_key
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetBond.type1
      ~TargetBond.type2
      ~TargetBond.element1
      ~TargetBond.element2
      ~TargetBond.bond_r
      ~TargetBond.bond_k
      ~TargetBond.funct
   
   